package com.mcwl.common.utils.bean;

import com.mcwl.common.utils.BetweenTimeUtil;


import com.mcwl.common.domain.RequestConditionEntity;
import com.mcwl.common.utils.ResponsePageEntity;
import com.mcwl.common.web.BaseMapper;
import lombok.extern.slf4j.Slf4j;

import java.util.List;

/**
 * 公共service
 */
@Slf4j
public abstract class BaseService<K, V> {
    /**
     * 获取BaseMapper
     *
     * @return BaseMapper
     */
    protected abstract BaseMapper getBaseMapper();
    /**
     * 用户自定义导出逻辑
     *
     * @param v 查询条件
     * @return 是否自定义
     */
    public boolean customizeExport(V v) {
        return false;
    }

    /**
     * 通用的分页接口
     *
     * @return 数据
     * @param s   分页请求参数
     * @param <T> 分页返回实体
     */
    public <S extends RequestConditionEntity, T> ResponsePageEntity<T> searchByPage(S s) {
        BetweenTimeUtil.parseTime(s);
        int count = getBaseMapper().searchCount(s);
        if (count == 0) {
            return ResponsePageEntity.buildEmpty(s);
        }
        List<T> dataList = getBaseMapper().searchByCondition(s);
        return ResponsePageEntity.build(s, count, dataList);
    }


}
